@@ -1,6 +1,6 @@
 package Math::BigInt::FastCalc;
 
-use 5.006002;
+use 5.006;
 use strict;
 # use warnings;	# dont use warnings for older Perls
 
@@ -11,7 +11,7 @@ use vars qw/@ISA $VERSION $BASE $BASE_LEN/;
 
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.14';
+$VERSION = '0.17';
 
 bootstrap Math::BigInt::FastCalc $VERSION;
 
@@ -26,15 +26,15 @@ BEGIN
   # use Calc to override the methods that we do not provide in XS
 
   for my $method (qw/
-    new str
+    str
     add sub mul div
     rsft lsft
     mod modpow modinv
     gcd
-    pow root sqrt log_int fac
+    pow root sqrt log_int fac nok
     digit check
     from_hex from_bin from_oct as_hex as_bin as_oct
-    zeros length base_len
+    zeros base_len
     xor or and
     alen 1ex
     /)
@@ -60,6 +60,7 @@ sub import
 
 1;
 __END__
+=pod
 
 =head1 NAME
 
